<?php
/**
 * 2008-2016 Chronopostfood SAS
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to chronopostfood@adexos.fr so we can send you a copy immediately.
 *
 * @author    Adexos for Chronopostfood <chronopostfood@adexos.fr>
 * @copyright 2008-2016 Chronopostfood SAS
 * @license   http://opensource.org/licenses/osl-3.0.php Open Software License (OSL 3.0)
 */

include('../../config/config.inc.php');
require_once('chronopostfood.php');

if (!defined('_MYDIR_')) {
    define('_MYDIR_', dirname(__FILE__));
}

if (!Tools::getIsset('shared_secret') || Tools::getValue('shared_secret') != Configuration::get('CHRONOFOOD_SECRET')) {
    die('Secret does not match.');
}

$cible = Tools::getValue('cible');

if ($cible) {
    /* export */
    header('Content-Disposition: attachment; filename="export'.$cible.date('Ymd').'.csv"');
    if ($cible == 'CSS') {
        header('Content-Type: text/plain; charset=ISO-8859-1');
        //include_once _MYDIR_.'/libraries/PointRelaisServiceWSService.php';
        foreach (_getChronoOrders() as $o) {
            /* Ingredients */
            $address = new Address($o->id_address_delivery);
            $country = new Country($address->id_country);
            $customer = new Customer($o->id_customer); /* for email address */
            $carrier = new Carrier($o->id_carrier);


            $details = Chronopostfood::getSkybillDetails($o);

            $bt = '';

            /* Stir everything together */
            echo $o->id.';';

            if ($address->company != '') {
                echo _c($address->company).';';
            } else {
                echo _c($address->firstname.' '.$address->lastname).';';
            }

            echo _c($address->firstname.' '.$address->lastname).';';
            echo ';'; // name 2

            echo _c($address->address1).';'._c($address->address2).';';
            echo ';'; // digicode

            echo _c($address->postcode).';';
            echo _c($address->city).';';
            echo $country->iso_code.';';
            if ($address->phone != '') {
                echo $address->phone.';';
            } else {
                echo $address->phone_mobile.';';
            }
            echo $customer->email.';';

            echo $o->id.';';
            echo ';'; /* ref expé 2 */

            echo $details['productCode'];
            echo ';';

            echo Configuration::get('CHRONOFOOD_GENERAL_ACCOUNT').';';
            echo Configuration::get('CHRONOFOOD_GENERAL_SUBACCOUNT').';';
            echo Chronopostfood::amountToInsure($o->id) > 0 ? Chronopostfood::amountToInsure($o->id) : ''.';';
            echo ';'; // Customs value
            echo 'M;';
            echo ';'; // Contents description
            if (Chronopostfood::isSaturdayOptionApplicable()) {
                echo 'Y;';
            } else {
                echo 'N;';
            }
            echo $bt.';';
            echo($o->getTotalWeight() == 0 ? 1 : ($o->getTotalWeight())).';';
            echo ';'; // width
            echo ';'; // length
            echo ';'; // height
            echo '1;'; // warn recipient
            echo Chronopostfood::minNumberOfPackages($o->id).';';
            echo date("d/m/Y").';';
            echo 'Y;';
            echo 'N;';
            echo Chronopostfood::getExpirationDate($o->id, 'd/m/Y') . ';'; // best before

            // RDV below
            if (array_key_exists('timeSlotStartDate', $details)) {
                echo $details['timeSlotStartDate'].';';
                echo $details['timeSlotEndDate'].';';
                echo $details['timeSlotTariffLevel'].';';
            } else {
                echo ';;;';
            }

            echo $details['service'];
            echo ';'."\r\n";
        }
    }

    if ($cible == 'CSO') {
        header('Content-Type: text/plain; charset=US-ASCII');

        foreach (_getChronoOrders(false) as $o) {
            /* Ingredients */
            $address = new Address($o->id_address_delivery);
            $country = new Country($address->id_country);
            $customer = new Customer($o->id_customer); /* for email address */
            $carrier = new Carrier($o->id_carrier);

            /* Stir everything together */
            echo ';'; /* "code destinataire" left empty */

            if ($address->company != '') {
                echo _c($address->company).';';
            } else {
                echo ';';
            }
            echo ';'; /* "suite raison sociale" (?) */
            echo _c($address->address1).';'._c($address->address2).';';
            echo ';'; /* "code porte" */

            echo $country->iso_code.';';
            echo _c($address->postcode).';';
            echo _c($address->city).';';
            echo _c($address->lastname).';';
            echo _c($address->firstname).';';
            if ($address->phone != '') {
                echo $address->phone.';';
            } else {
                echo $address->phone_mobile.';';
            }
            echo $customer->email.';';
            echo ';'; /* "numero tva" */

            if ($carrier->id_reference == Configuration::get('CHRONOFOOD_CHRONO13_ID')) {
                echo '1';
            }
            if ($carrier->id_reference == Configuration::get('CHRONOFOOD_CHRONOEXPRESS_ID')) {
                echo '4';
            }
            echo ';';

            echo $o->id.';';
            echo($o->getTotalWeight() == 0 ? 1 : ($o->getTotalWeight() * 1000)).';';

            echo ';;;';
            echo Configuration::get('CHRONOFOOD_GENERAL_SUBACCOUNT').';';
            echo '1;Commande '.$o->id.';';
            echo ';';
            echo $o->total_paid.';';

            if (Chronopostfood::isSaturdayOptionApplicable()) {
                echo '1;';
            } else {
                echo '2;';
            }
            echo "\r\n";
        }
    }
}

function _c($value)
{
    return utf8_decode(str_replace('"', ' ', str_replace(';', ' ', strip_tags($value))));
}

function _getChronoOrders($withRelais = true)
{
    if (Tools::getIsset('multi')) {
        $multi = Tools::jsonDecode(Tools::getValue('multi'), true);
    } else {
        $multi = array();
    }

    $r = array();
    if (Tools::getIsset('orders')) {
        $o = explode(';', Tools::getValue('orders'));
    } else {
        $o = Order::getOrdersIdByDate(date('Y-m-d H:i:s', 0), date('Y-m-d H:i:s'));
    }

    foreach ($o as $i) {
        $or = new Order($i);

        if ($withRelais) {
            if (Chronopostfood::isChrono($or->id_carrier)) {
                if (array_key_exists($i, $multi)) {
                    $cpt = $multi[$i];
                } else {
                    $cpt = 1;
                }

                for (; $cpt > 0; $cpt--) {
                    $r[] = $or;
                }
            }
        } else { // no relais export for CSO
            if (Chronopostfood::isChrono($or->id_carrier) && !Chronopostfood::isRelais($or->id_carrier)) {
                if (array_key_exists($i, $multi)) {
                    $cpt = $multi[$i];
                } else {
                    $cpt = 1;
                }

                for (; $cpt > 0; $cpt--) {
                    $r[] = $or;
                }
            }
        }
    }
    return $r;
}
